searchData={"items":[{"type":"module","title":"usb","doc":"Erlang interface for interacting with USB devices.","ref":"usb.html"},{"type":"function","title":"usb.attach_kernel_driver/2","doc":null,"ref":"usb.html#attach_kernel_driver/2"},{"type":"function","title":"usb.claim_interface/2","doc":"Claim an interface on a given device handle. You must claim the interface you wish to use before you can perform I/O on any of its endpoints. It is legal to attempt to claim an already-claimed interface, in which case this function just returns ok without doing anything. Claiming of interfaces is a purely logical operation; it does not cause any requests to be sent over the bus. Interface claiming is used to instruct the underlying operating system that your application wishes to take ownership of the interface.","ref":"usb.html#claim_interface/2"},{"type":"function","title":"usb.clear_halt/2","doc":"Clear the halt/stall condition for an endpoint. Endpoints with halt status are unable to receive or transmit data until the halt condition is stalled. You should cancel all pending transfers before attempting to clear the halt condition.","ref":"usb.html#clear_halt/2"},{"type":"function","title":"usb.close_device/1","doc":"Close a device handle.","ref":"usb.html#close_device/1"},{"type":"function","title":"usb.demonitor_hotplug/1","doc":"Stop listening for hotplug events.","ref":"usb.html#demonitor_hotplug/1"},{"type":"function","title":"usb.detach_kernel_driver/2","doc":null,"ref":"usb.html#detach_kernel_driver/2"},{"type":"function","title":"usb.get_bus_number/1","doc":"Get the number of the bus that a device is connected to.","ref":"usb.html#get_bus_number/1"},{"type":"function","title":"usb.get_config_descriptor/2","doc":"Get a USB configuration descriptor based on its index.","ref":"usb.html#get_config_descriptor/2"},{"type":"function","title":"usb.get_device_address/1","doc":"Get the address of the device on the bus it is connected to.","ref":"usb.html#get_device_address/1"},{"type":"function","title":"usb.get_device_descriptor/1","doc":"Get the USB device descriptor for a given device.","ref":"usb.html#get_device_descriptor/1"},{"type":"function","title":"usb.get_device_list/0","doc":"Returns a list of USB devices currently attached to the system.","ref":"usb.html#get_device_list/0"},{"type":"function","title":"usb.get_device_speed/1","doc":"Get the negotiated connection speed for a device.","ref":"usb.html#get_device_speed/1"},{"type":"function","title":"usb.get_port_number/1","doc":"Get the number of the port that a device is connected to.","ref":"usb.html#get_port_number/1"},{"type":"function","title":"usb.get_port_numbers/1","doc":"Get the list of all port numbers from root for the specified device.","ref":"usb.html#get_port_numbers/1"},{"type":"function","title":"usb.monitor_hotplug/0","doc":"Equivalent to monitor_hotplug([]) . start listening for hotplug events.","ref":"usb.html#monitor_hotplug/0"},{"type":"function","title":"usb.monitor_hotplug/1","doc":"start listening for hotplug events. The owner process will start receiving the following hotplug events: {usb, device_arrived, Device} and {usb, device_left, Device} . If the enumerate flag is provided, the owner process will received device_arrived events for all devices already plugged into the host.","ref":"usb.html#monitor_hotplug/1"},{"type":"function","title":"usb.open_device/1","doc":"Open a device and obtain a device handle. A handle allows you to perform I/O on the device in question.","ref":"usb.html#open_device/1"},{"type":"function","title":"usb.read_bulk/4","doc":null,"ref":"usb.html#read_bulk/4"},{"type":"function","title":"usb.read_control/7","doc":null,"ref":"usb.html#read_control/7"},{"type":"function","title":"usb.read_interrupt/4","doc":null,"ref":"usb.html#read_interrupt/4"},{"type":"function","title":"usb.release_interface/2","doc":"Release an interface previously claimed with claim_interface/2 . You should release all claimed interfaces before closing a device handle.","ref":"usb.html#release_interface/2"},{"type":"function","title":"usb.set_configuration/2","doc":null,"ref":"usb.html#set_configuration/2"},{"type":"function","title":"usb.write_bulk/4","doc":null,"ref":"usb.html#write_bulk/4"},{"type":"function","title":"usb.write_control/7","doc":null,"ref":"usb.html#write_control/7"},{"type":"function","title":"usb.write_interrupt/4","doc":null,"ref":"usb.html#write_interrupt/4"},{"type":"type","title":"usb.alt_setting/0","doc":null,"ref":"usb.html#t:alt_setting/0"},{"type":"type","title":"usb.config_descriptor/0","doc":null,"ref":"usb.html#t:config_descriptor/0"},{"type":"opaque","title":"usb.device/0","doc":"Reference to a USB device attached to the host system.","ref":"usb.html#t:device/0"},{"type":"type","title":"usb.device_descriptor/0","doc":"A map representing the standard USB device descriptor. This descriptor is documented in section 9.6.1 of the USB 3.0 specification.","ref":"usb.html#t:device_descriptor/0"},{"type":"opaque","title":"usb.device_handle/0","doc":"A referenced to an open USB device. This handle is used to perform I/O and other operations. When finished with a device handle, you should call close_device/1 .","ref":"usb.html#t:device_handle/0"},{"type":"type","title":"usb.device_speed/0","doc":"Indicates the speed at which the device is operating. unknown The OS doesn't report or know the device speed. low The device is operating at low speed (1.5MBit/s). full The device is operating at full speed (12MBit/s). high The device is operating at high speed (480MBit/s). super The device is operating at super speed (5000MBit/s). super_plus The device is operating at super speed plus (10000MBit/s).","ref":"usb.html#t:device_speed/0"},{"type":"type","title":"usb.endpoint/0","doc":null,"ref":"usb.html#t:endpoint/0"},{"type":"opaque","title":"usb.hotplug_monitor/0","doc":null,"ref":"usb.html#t:hotplug_monitor/0"},{"type":"type","title":"usb.interface_descriptor/0","doc":null,"ref":"usb.html#t:interface_descriptor/0"},{"type":"type","title":"usb.monitor_hotplug_flag/0","doc":null,"ref":"usb.html#t:monitor_hotplug_flag/0"},{"type":"extras","title":"Overview","doc":"# usb\n\nAn Erlang application for interfacing with USB peripherals using libusb.\n\nThis application allows for discovering and communicating with USB peripherals by making use of libusb through a NIF interface.\n\n# Dependencies\n\nThis Erlang application library depends on:\n\n* `pkg-config` (build only)\n* `libusb` ≥ 1.0.16\n\n# Setup\n\nYou need to add `usb` as a dependency to your project. If you are using `rebar3`, you can add the following to your `rebar.config`:\n\n```erlang\n{deps, [\n    {usb, \"0.2.1\"}\n]}.\n```\n\nAlso ensure that `usb` is added as a dependency to your application, by\nupdating your `.app.src` file:\n\n```erlang\n{application, my_app, [\n\n    {applications, [\n        kernel,\n        stdlib,\n\n        usb  % <- You need this in your applications list\n    ]}\n]}.\n```\n\n# Usage","ref":"readme.html"},{"type":"extras","title":"Listing and querying devices - Overview","doc":"You can list currently connected USB devices, you can use:\n\n```erlang\n> {ok, [Device|_]} = usb:get_device_list().\n{ok,[#Ref<0.1223016592.607256583.114769>]}.\n```\n\nYou can then query the device:\n\n```erlang\n> usb:get_device_speed(Device).\n{ok, high}\n> usb:get_device_descriptor(Device).\n{ok, #{\n    class_code => 0,\n    device_version => 532,\n    manufacturer_string_index => 1,\n    max_packet_size0 => 64,\n    num_configurations => 1,\n    product_id => 33028,\n    product_string_index => 0,\n    protocol_code => 0,\n    serial_number_string_index => 2,\n    sub_class_code => 0,\n    usb_version => 512,\n    vendor_id => 1452\n}}\n> usb:get_config_descriptor(Device, 0).\n{ok, #{\n    attributes => 224,\n    configuration_number => 1,\n    description_string_index => 0,\n    extra => <<>>,\n    interfaces => [\n        #{alt_settings => [\n            #{\n                class_code => 3,\n                description_string_index => 4,\n                endpoints => [\n                    #{\n                        address => 129,\n                        attributes => 3,\n                        extra => <<>>,\n                        interval => 1,\n                        max_packet_size => 8,\n                        refresh => 0,\n                        synch_address => 0\n                    }\n                ],\n                extra => <<9,33,1,1,0,1,34,179,0>>,\n                interface_number => 0,\n                protocol_code => 0,\n                setting_number => 0,\n                sub_class_code => 0\n            }\n        ]}\n    ],\n    max_power => 500\n}}\n```","ref":"readme.html#listing-and-querying-devices"},{"type":"extras","title":"Monitoring USB device hotplug - Overview","doc":"The following will start monotoring for USB device arrival and departure:\n\n```erlang\n> {ok, Monitor} = usb:monitor_hotplug([enumerate]).\n{ok, #Ref<0.731181930.70909953.42752>}\n```\n\nThe `enumerate` option will create hotplug notifications about already plugged\nin devices. Without the option, only newly connected devices will be reported.\n\nFrom this point on, the process monitoring USB hotplug will received one of the following messages:\n\n* `{usb, device_arrived, Device}`\n* `{usb, device_left, Device}`\n\nwhere `Device` is an opaque reference representing a specific device. these references can be used to interact with the device.","ref":"readme.html#monitoring-usb-device-hotplug"},{"type":"extras","title":"License","doc":"# Apache License\nVersion 2.0, January 2004\n\nhttp://www.apache.org/licenses/\n\nTERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION","ref":"license.html"},{"type":"extras","title":"1. Definitions. - License","doc":"\"License\" shall mean the terms and conditions for use, reproduction, and\ndistribution as defined by Sections 1 through 9 of this document.\n\n\"Licensor\" shall mean the copyright owner or entity authorized by the copyright\nowner that is granting the License.\n\n\"Legal Entity\" shall mean the union of the acting entity and all other entities\nthat control, are controlled by, or are under common control with that entity.\nFor the purposes of this definition, \"control\" means (i) the power, direct or\nindirect, to cause the direction or management of such entity, whether by\ncontract or otherwise, or (ii) ownership of fifty percent (50%) or more of the\noutstanding shares, or (iii) beneficial ownership of such entity.\n\n\"You\" (or \"Your\") shall mean an individual or Legal Entity exercising\npermissions granted by this License.\n\n\"Source\" form shall mean the preferred form for making modifications, including\nbut not limited to software source code, documentation source, and configuration\nfiles.\n\n\"Object\" form shall mean any form resulting from mechanical transformation or\ntranslation of a Source form, including but not limited to compiled object code,\ngenerated documentation, and conversions to other media types.\n\n\"Work\" shall mean the work of authorship, whether in Source or Object form, made\navailable under the License, as indicated by a copyright notice that is included\nin or attached to the work (an example is provided in the Appendix below).\n\n\"Derivative Works\" shall mean any work, whether in Source or Object form, that\nis based on (or derived from) the Work and for which the editorial revisions,\nannotations, elaborations, or other modifications represent, as a whole, an\noriginal work of authorship. For the purposes of this License, Derivative Works\nshall not include works that remain separable from, or merely link (or bind by\nname) to the interfaces of, the Work and Derivative Works thereof.\n\n\"Contribution\" shall mean any work of authorship, including the original version\nof the Work and any modifications or additions to that Work or Derivative Works\nthereof, that is intentionally submitted to Licensor for inclusion in the Work\nby the copyright owner or by an individual or Legal Entity authorized to submit\non behalf of the copyright owner. For the purposes of this definition,\n\"submitted\" means any form of electronic, verbal, or written communication sent\nto the Licensor or its representatives, including but not limited to\ncommunication on electronic mailing lists, source code control systems, and\nissue tracking systems that are managed by, or on behalf of, the Licensor for\nthe purpose of discussing and improving the Work, but excluding communication\nthat is conspicuously marked or otherwise designated in writing by the copyright\nowner as \"Not a Contribution.\"\n\n\"Contributor\" shall mean Licensor and any individual or Legal Entity on behalf\nof whom a Contribution has been received by Licensor and subsequently\nincorporated within the Work.","ref":"license.html#1-definitions"},{"type":"extras","title":"2. Grant of Copyright License. - License","doc":"Subject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable copyright license to reproduce, prepare Derivative Works of,\npublicly display, publicly perform, sublicense, and distribute the Work and such\nDerivative Works in Source or Object form.","ref":"license.html#2-grant-of-copyright-license"},{"type":"extras","title":"3. Grant of Patent License. - License","doc":"Subject to the terms and conditions of this License, each Contributor hereby\ngrants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free,\nirrevocable (except as stated in this section) patent license to make, have\nmade, use, offer to sell, sell, import, and otherwise transfer the Work, where\nsuch license applies only to those patent claims licensable by such Contributor\nthat are necessarily infringed by their Contribution(s) alone or by combination\nof their Contribution(s) with the Work to which such Contribution(s) was\nsubmitted. If You institute patent litigation against any entity (including a\ncross-claim or counterclaim in a lawsuit) alleging that the Work or a\nContribution incorporated within the Work constitutes direct or contributory\npatent infringement, then any patent licenses granted to You under this License\nfor that Work shall terminate as of the date such litigation is filed.","ref":"license.html#3-grant-of-patent-license"},{"type":"extras","title":"4. Redistribution. - License","doc":"You may reproduce and distribute copies of the Work or Derivative Works thereof\nin any medium, with or without modifications, and in Source or Object form,\nprovided that You meet the following conditions:\n\n1. You must give any other recipients of the Work or Derivative Works a copy of\n   this License; and\n\n2. You must cause any modified files to carry prominent notices stating that\n   You changed the files; and\n\n3. You must retain, in the Source form of any Derivative Works that You\n   distribute, all copyright, patent, trademark, and attribution notices from\n   the Source form of the Work, excluding those notices that do not pertain to\n   any part of the Derivative Works; and\n\n4. If the Work includes a \"NOTICE\" text file as part of its distribution, then\n   any Derivative Works that You distribute must include a readable copy of the\n   attribution notices contained within such NOTICE file, excluding those\n   notices that do not pertain to any part of the Derivative Works, in at least\n   one of the following places: within a NOTICE text file distributed as part\n   of the Derivative Works; within the Source form or documentation, if\n   provided along with the Derivative Works; or, within a display generated by\n   the Derivative Works, if and wherever such third-party notices normally\n   appear. The contents of the NOTICE file are for informational purposes only\n   and do not modify the License. You may add Your own attribution notices\n   within Derivative Works that You distribute, alongside or as an addendum to\n   the NOTICE text from the Work, provided that such additional attribution\n   notices cannot be construed as modifying the License.\n\nYou may add Your own copyright statement to Your modifications and may provide\nadditional or different license terms and conditions for use, reproduction, or\ndistribution of Your modifications, or for any such Derivative Works as a whole,\nprovided Your use, reproduction, and distribution of the Work otherwise complies\nwith the conditions stated in this License.","ref":"license.html#4-redistribution"},{"type":"extras","title":"5. Submission of Contributions. - License","doc":"Unless You explicitly state otherwise, any Contribution intentionally submitted\nfor inclusion in the Work by You to the Licensor shall be under the terms and\nconditions of this License, without any additional terms or conditions.\nNotwithstanding the above, nothing herein shall supersede or modify the terms of\nany separate license agreement you may have executed with Licensor regarding\nsuch Contributions.","ref":"license.html#5-submission-of-contributions"},{"type":"extras","title":"6. Trademarks. - License","doc":"This License does not grant permission to use the trade names, trademarks,\nservice marks, or product names of the Licensor, except as required for\nreasonable and customary use in describing the origin of the Work and\nreproducing the content of the NOTICE file.","ref":"license.html#6-trademarks"},{"type":"extras","title":"7. Disclaimer of Warranty. - License","doc":"Unless required by applicable law or agreed to in writing, Licensor provides the\nWork (and each Contributor provides its Contributions) on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied,\nincluding, without limitation, any warranties or conditions of TITLE, NON-\nINFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are\nsolely responsible for determining the appropriateness of using or\nredistributing the Work and assume any risks associated with Your exercise of\npermissions under this License.","ref":"license.html#7-disclaimer-of-warranty"},{"type":"extras","title":"8. Limitation of Liability. - License","doc":"In no event and under no legal theory, whether in tort (including negligence),\ncontract, or otherwise, unless required by applicable law (such as deliberate\nand grossly negligent acts) or agreed to in writing, shall any Contributor be\nliable to You for damages, including any direct, indirect, special, incidental,\nor consequential damages of any character arising as a result of this License or\nout of the use or inability to use the Work (including but not limited to\ndamages for loss of goodwill, work stoppage, computer failure or malfunction, or\nany and all other commercial damages or losses), even if such Contributor has\nbeen advised of the possibility of such damages.","ref":"license.html#8-limitation-of-liability"},{"type":"extras","title":"9. Accepting Warranty or Additional Liability. - License","doc":"While redistributing the Work or Derivative Works thereof, You may choose to\noffer, and charge a fee for, acceptance of support, warranty, indemnity, or\nother liability obligations and/or rights consistent with this License. However,\nin accepting such obligations, You may act only on Your own behalf and on Your\nsole responsibility, not on behalf of any other Contributor, and only if You\nagree to indemnify, defend, and hold each Contributor harmless for any liability\nincurred by, or claims asserted against, such Contributor by reason of your\naccepting any such warranty or additional liability.\n\nEND OF TERMS AND CONDITIONS","ref":"license.html#9-accepting-warranty-or-additional-liability"},{"type":"extras","title":"Copyright","doc":"Copyright, KOPERA AS  . All Rights Reserved.","ref":"notice.html"}],"proglang":"erlang","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}